==> invoice-client-4.1.5-20200206.054535-14-sources.jar: com/xforceplus/seller/invoice/client/model/ApplyRedNotifucationRequest.java <==
package com.xforceplus.seller.invoice.client.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;

import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;

/**
 * @author <a href="mail to: libaozhong@xforceplus.com" rel="nofollow">libaozhong</a>
 * @Description: [功能描述]
 * @version: 1.0
 * @CreateDate: 2019-08-08 13:11</p>
 */
@JsonInclude(NON_NULL)
public class ApplyRedNotifucationRequest {


    public Integer getApplyType() {
        return applyType;
    }

    public void setApplyType(Integer applyType) {
        this.applyType = applyType;
    }

    @ApiModelProperty(value = "申请类型 购方发起:0-已抵扣1-未抵扣 销方发起:2-开票有误 ")
    @JsonProperty("applyType")
   private Integer applyType;
    @ApiModelProperty(value = "1。销方 2。购方")
    @JsonProperty("userRole")
   private Integer userRole;
    @ApiModelProperty(value = "票据id")
    @JsonProperty("invoiceId")
    private Long invoiceId;

    public Integer getUserRole() {
        return userRole;
    }

    public void setUserRole(Integer userRole) {
        this.userRole = userRole;
    }

    public Long getInvoiceId() {
        return invoiceId;
    }

    public void setInvoiceId(Long invoiceId) {
        this.invoiceId = invoiceId;
    }

    public String getDeviceUn() {
        return deviceUn;
    }

    public void setDeviceUn(String deviceUn) {
        this.deviceUn = deviceUn;
    }

    public String getTerminalUn() {
        return terminalUn;
    }

    public void setTerminalUn(String terminalUn) {
        this.terminalUn = terminalUn;
    }

    @ApiModelProperty(value = "设备编号")
    @JsonProperty("deviceUn")
    private String deviceUn;
    @ApiModelProperty(value = "终端编号")
    @JsonProperty("terminalUn")
    private String terminalUn;

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ApplyRedNotifucationRequest that = (ApplyRedNotifucationRequest) o;
        return Objects.equals(invoiceId, that.invoiceId) &&
                Objects.equals(deviceUn, that.deviceUn) &&
                Objects.equals(terminalUn, that.terminalUn);
    }

    @Override
    public int hashCode() {
        return Objects.hash(invoiceId, deviceUn, terminalUn);
    }
}

==> invoice-client-4.1.12-20201012.074128-2-sources.jar: com/xforceplus/seller/invoice/client/model/ApplyRedNotifucationRequest.java <==
package com.xforceplus.seller.invoice.client.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModelProperty;

import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;

/**
 * @author <a href="mail to: libaozhong@xforceplus.com" rel="nofollow">libaozhong</a>
 * @Description: [功能描述]
 * @version: 1.0
 * @CreateDate: 2019-08-08 13:11</p>
 */
@JsonInclude(NON_NULL)
public class ApplyRedNotifucationRequest {


    public Integer getApplyType() {
        return applyType;
    }

    public void setApplyType(Integer applyType) {
        this.applyType = applyType;
    }

    @ApiModelProperty(value = "申请类型 购方发起:0-已抵扣1-未抵扣 销方发起:2-开票有误 ")
    @JsonProperty("applyType")
   private Integer applyType;
    @ApiModelProperty(value = "1。销方 2。购方")
    @JsonProperty("userRole")
   private Integer userRole;
    @ApiModelProperty(value = "票据id")
    @JsonProperty("invoiceId")
    private Long invoiceId;

    @ApiModelProperty(value = "原发票类型")
    @JsonProperty("originInvoiceType")
    private String  originInvoiceType ;

    public String getOriginInvoiceType() {
        return originInvoiceType;
    }

    public void setOriginInvoiceType(String originInvoiceType) {
        this.originInvoiceType = originInvoiceType;
    }

    public Integer getUserRole() {
        return userRole;
    }

    public void setUserRole(Integer userRole) {
        this.userRole = userRole;
    }

    public Long getInvoiceId() {
        return invoiceId;
    }

    public void setInvoiceId(Long invoiceId) {
        this.invoiceId = invoiceId;
    }

    public String getDeviceUn() {
        return deviceUn;
    }

    public void setDeviceUn(String deviceUn) {
        this.deviceUn = deviceUn;
    }

    public String getTerminalUn() {
        return terminalUn;
    }

    public void setTerminalUn(String terminalUn) {
        this.terminalUn = terminalUn;
    }

    @ApiModelProperty(value = "设备编号")
    @JsonProperty("deviceUn")
    private String deviceUn;
    @ApiModelProperty(value = "终端编号")
    @JsonProperty("terminalUn")
    private String terminalUn;

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ApplyRedNotifucationRequest that = (ApplyRedNotifucationRequest) o;
        return Objects.equals(invoiceId, that.invoiceId) &&
                Objects.equals(deviceUn, that.deviceUn) &&
                Objects.equals(terminalUn, that.terminalUn);
    }

    @Override
    public int hashCode() {
        return Objects.hash(invoiceId, deviceUn, terminalUn);
    }
}
